@@ -8,9 +8,9 @@ import (
 	"sync"
 
 	"github.com/containers/common/pkg/config"
-	"github.com/containers/podman/v4/pkg/domain/entities"
-	"github.com/containers/podman/v4/pkg/rootless"
-	"github.com/containers/podman/v4/pkg/util"
+	"github.com/containers/podman/v5/pkg/domain/entities"
+	"github.com/containers/podman/v5/pkg/rootless"
+	"github.com/containers/podman/v5/pkg/util"
 	"github.com/spf13/cobra"
 	"github.com/spf13/pflag"
 )
@@ -72,7 +72,7 @@ func containersConfModules() ([]string, error) {
 	fs.ParseErrorsWhitelist.UnknownFlags = true
 	fs.Usage = func() {}
 	fs.SetInterspersed(false)
-	fs.StringSliceVar(&modules, "module", nil, "")
+	fs.StringArrayVar(&modules, "module", nil, "")
 	fs.BoolP("help", "h", false, "") // Need a fake help flag to avoid the `pflag: help requested` error
 	return modules, fs.Parse(os.Args[index:])
 }
@@ -80,7 +80,7 @@ func containersConfModules() ([]string, error) {
 func newPodmanConfig() {
 	modules, err := containersConfModules()
 	if err != nil {
-		fmt.Fprintln(os.Stderr, err.Error())
+		fmt.Fprintf(os.Stderr, "Error parsing containers.conf modules: %v\n", err)
 		os.Exit(1)
 	}
 
@@ -94,7 +94,7 @@ func newPodmanConfig() {
 		Modules:    modules,
 	})
 	if err != nil {
-		fmt.Fprint(os.Stderr, "Failed to obtain podman configuration: "+err.Error())
+		fmt.Fprintf(os.Stderr, "Failed to obtain podman configuration: %v\n", err)
 		os.Exit(1)
 	}
 
@@ -111,7 +111,7 @@ func newPodmanConfig() {
 			mode = entities.TunnelMode
 		}
 	default:
-		fmt.Fprintf(os.Stderr, "%s is not a supported OS", runtime.GOOS)
+		fmt.Fprintf(os.Stderr, "%s is not a supported OS\n", runtime.GOOS)
 		os.Exit(1)
 	}
 
@@ -134,7 +134,7 @@ func setXdgDirs() error {
 
 	// Set up XDG_RUNTIME_DIR
 	if _, found := os.LookupEnv("XDG_RUNTIME_DIR"); !found {
-		dir, err := util.GetRuntimeDir()
+		dir, err := util.GetRootlessRuntimeDir()
 		if err != nil {
 			return err
 		}
@@ -166,3 +166,19 @@ func setXdgDirs() error {
 	}
 	return nil
 }
+
+func RetryDefault() uint {
+	if IsRemote() {
+		return 0
+	}
+
+	return PodmanConfig().ContainersConfDefaultsRO.Engine.Retry
+}
+
+func RetryDelayDefault() string {
+	if IsRemote() {
+		return ""
+	}
+
+	return PodmanConfig().ContainersConfDefaultsRO.Engine.RetryDelay
+}
