@@ -9,49 +9,19 @@ import (
 
 	nettypes "github.com/containers/common/libnetwork/types"
 	netutil "github.com/containers/common/libnetwork/util"
-	"github.com/containers/podman/v4/libpod"
-	"github.com/containers/podman/v4/libpod/define"
-	"github.com/containers/podman/v4/pkg/api/handlers/utils"
-	api "github.com/containers/podman/v4/pkg/api/types"
-	"github.com/containers/podman/v4/pkg/domain/entities"
-	"github.com/containers/podman/v4/pkg/domain/infra/abi"
-	"github.com/containers/podman/v4/pkg/util"
+	"github.com/containers/podman/v5/libpod"
+	"github.com/containers/podman/v5/libpod/define"
+	"github.com/containers/podman/v5/pkg/api/handlers/utils"
+	api "github.com/containers/podman/v5/pkg/api/types"
+	"github.com/containers/podman/v5/pkg/domain/entities"
+	"github.com/containers/podman/v5/pkg/domain/infra/abi"
+	"github.com/containers/podman/v5/pkg/util"
 	"github.com/docker/docker/api/types"
 
 	dockerNetwork "github.com/docker/docker/api/types/network"
 	"github.com/sirupsen/logrus"
 )
 
-type containerNetStatus struct {
-	name   string
-	id     string
-	status map[string]nettypes.StatusBlock
-}
-
-func getContainerNetStatuses(rt *libpod.Runtime) ([]containerNetStatus, error) {
-	cons, err := rt.GetAllContainers()
-	if err != nil {
-		return nil, err
-	}
-	statuses := make([]containerNetStatus, 0, len(cons))
-	for _, con := range cons {
-		status, err := con.GetNetworkStatus()
-		if err != nil {
-			if errors.Is(err, define.ErrNoSuchCtr) || errors.Is(err, define.ErrCtrRemoved) {
-				continue
-			}
-			return nil, err
-		}
-
-		statuses = append(statuses, containerNetStatus{
-			id:     con.ID(),
-			name:   con.Name(),
-			status: status,
-		})
-	}
-	return statuses, nil
-}
-
 func normalizeNetworkName(rt *libpod.Runtime, name string) (string, bool) {
 	if name == nettypes.BridgeNetworkDriver {
 		return rt.Network().DefaultNetworkName(), true
@@ -86,7 +56,8 @@ func InspectNetwork(w http.ResponseWriter, r *http.Request) {
 		utils.NetworkNotFound(w, name, err)
 		return
 	}
-	statuses, err := getContainerNetStatuses(runtime)
+	ic := abi.ContainerEngine{Libpod: runtime}
+	statuses, err := ic.GetContainerNetStatuses()
 	if err != nil {
 		utils.InternalServerError(w, err)
 		return
@@ -95,10 +66,10 @@ func InspectNetwork(w http.ResponseWriter, r *http.Request) {
 	utils.WriteResponse(w, http.StatusOK, report)
 }
 
-func convertLibpodNetworktoDockerNetwork(runtime *libpod.Runtime, statuses []containerNetStatus, network *nettypes.Network, changeDefaultName bool) *types.NetworkResource {
+func convertLibpodNetworktoDockerNetwork(runtime *libpod.Runtime, statuses []abi.ContainerNetStatus, network *nettypes.Network, changeDefaultName bool) *types.NetworkResource {
 	containerEndpoints := make(map[string]types.EndpointResource, len(statuses))
 	for _, st := range statuses {
-		if netData, ok := st.status[network.Name]; ok {
+		if netData, ok := st.Status[network.Name]; ok {
 			ipv4Address := ""
 			ipv6Address := ""
 			macAddr := ""
@@ -116,12 +87,12 @@ func convertLibpodNetworktoDockerNetwork(runtime *libpod.Runtime, statuses []con
 				break
 			}
 			containerEndpoint := types.EndpointResource{
-				Name:        st.name,
+				Name:        st.Name,
 				MacAddress:  macAddr,
 				IPv4Address: ipv4Address,
 				IPv6Address: ipv6Address,
 			}
-			containerEndpoints[st.id] = containerEndpoint
+			containerEndpoints[st.ID] = containerEndpoint
 		}
 	}
 	ipamConfigs := make([]dockerNetwork.IPAMConfig, 0, len(network.Subnets))
@@ -192,7 +163,7 @@ func ListNetworks(w http.ResponseWriter, r *http.Request) {
 		utils.InternalServerError(w, err)
 		return
 	}
-	statuses, err := getContainerNetStatuses(runtime)
+	statuses, err := ic.GetContainerNetStatuses()
 	if err != nil {
 		utils.InternalServerError(w, err)
 		return
@@ -308,7 +279,10 @@ func CreateNetwork(w http.ResponseWriter, r *http.Request) {
 	}
 
 	opts := nettypes.NetworkCreateOptions{
-		IgnoreIfExists: !networkCreate.CheckDuplicate,
+		// networkCreate.CheckDuplicate is deprecated since API v1.44,
+		// but it defaults to true when sent by the client package to
+		// older daemons.
+		IgnoreIfExists: false,
 	}
 	ic := abi.ContainerEngine{Libpod: runtime}
 	newNetwork, err := ic.NetworkCreate(r.Context(), network, &opts)
@@ -448,6 +422,10 @@ func Connect(w http.ResponseWriter, r *http.Request) {
 			utils.Error(w, http.StatusNotFound, err)
 			return
 		}
+		if errors.Is(err, define.ErrNetworkConnected) {
+			utils.Error(w, http.StatusForbidden, err)
+			return
+		}
 		utils.Error(w, http.StatusInternalServerError, err)
 		return
 	}
